Index: src/test/org/apache/lucene/index/TestUnicodeTermEnum.java
===================================================================
--- src/test/org/apache/lucene/index/TestUnicodeTermEnum.java	(revision 0)
+++ src/test/org/apache/lucene/index/TestUnicodeTermEnum.java	(revision 0)
@@ -0,0 +1,31 @@
+package org.apache.lucene.index;
+
+import org.apache.lucene.analysis.KeywordAnalyzer;
+import org.apache.lucene.document.Document;
+import org.apache.lucene.document.Field;
+import org.apache.lucene.store.RAMDirectory;
+
+import junit.framework.TestCase;
+
+/**
+ * Test that you can seek to a lead surrogate in the term dictionary.
+ * this is existing supported behavior, because it is a valid unicode string,
+ * even though it cannot be represented in UTF-8 bytes.
+ */
+public class TestUnicodeTermEnum extends TestCase {
+  public void testSeekSurrogate() throws Exception {
+    RAMDirectory dir = new RAMDirectory();
+    IndexWriter writer = new IndexWriter(dir, new KeywordAnalyzer(), IndexWriter.MaxFieldLength.UNLIMITED);
+    Document d = new Document();
+    Field f = new Field("field", "", Field.Store.NO, Field.Index.ANALYZED);
+    d.add(f);
+    f.setValue("abacadaba");
+    writer.addDocument(d);
+    f.setValue("𩬅");
+    writer.addDocument(d);
+    writer.close();
+    IndexReader reader = IndexReader.open(dir, true);
+    TermEnum te = reader.terms(new Term("field", "𩬅".substring(0,1)));
+    assertEquals(new Term("field", "𩬅"), te.term());
+  }
+}

Property changes on: src\test\org\apache\lucene\index\TestUnicodeTermEnum.java
___________________________________________________________________
Added: svn:eol-style
   + native

